@@ -484,6 +484,7 @@ def standardProgressBarWidth() -> int:
     return int(QFontMetrics(QFont()).height() * 20)
 
 
+# Be sure to update gvfs_controls_mounts() if updating this
 class Desktop(Enum):
     gnome = 1
     unity = 2
@@ -495,13 +496,15 @@ class Desktop(Enum):
     lxqt = 8
     ubuntugnome = 9
     popgnome = 10
-    unknown = 11
+    deepin = 11
+    unknown = 12
 
 
 class FileManagerType(Enum):
     regular = 1
     select = 2
     dir_only_uri = 3
+    show_item = 4
 
 
 FileManagerBehavior = dict(
@@ -513,6 +516,7 @@ FileManagerBehavior = dict(
     pcmanfm=FileManagerType.dir_only_uri,
 )
 FileManagerBehavior['pcmanfm-qt'] = FileManagerType.dir_only_uri
+FileManagerBehavior['dde-file-manager'] = FileManagerType.show_item
 
 
 DefaultFileBrowserFallback = dict(
@@ -526,6 +530,7 @@ DefaultFileBrowserFallback = dict(
     xfce='thunar',
     lxde='pcmanfm',
     lxqt='pcmanfm-qt',
+    deepin='dde-file-manager',
 )
 
 
@@ -545,6 +550,7 @@ class Distro(Enum):
     elementary = 13
     centos = 14
     gentoo = 15
+    deepin = 16
     unknown = 20
 
 
@@ -633,6 +639,7 @@ datetime_offset_exiftool = dict(
     rw2=709636,
     sr2=836,
     srw=496,
+    x3f=69220070,
     mts=5000,
     m2t=5000,
     m2ts=5000,
@@ -679,6 +686,7 @@ all_tags_offset_exiftool = dict(
     rw2=1205458,
     sr2=1080,
     srw=222418,
+    x3f=7380128,
     mp4=130000,
     mts=1300000,
     mt2=1300000,
